class AgileUpException(Exception):
    """An exception that AgileUp can handle and show to the user."""

    def __init__(self, message: str) -> None:
        super().__init__(message)
        self.message = message

    def format_message(self) -> str:
        return self.message

    def __str__(self) -> str:
        return self.message
